@@ -4,8 +4,9 @@ import datetime
 import os
 import sys
 import traceback
+from itertools import tee
 from pathlib import Path
-from typing import Any, Dict, Iterator, List, NoReturn, Optional, Union, cast
+from typing import Any, Dict, Iterator, List, NoReturn, Optional, Set, Union
 
 import humanize
 from rich.console import Console
@@ -179,7 +180,7 @@ def local(team: Optional[str] = None) -> None:
     Parameters
     ----------
     team: Optional[str]
-        The name of the team to list, or the defautl one if no team is given. Defaults to None.
+        The name of the team to list, or the default one if no team is given. Defaults to None.
     """
     table: Table = Table(show_header=True, header_style="bold cyan")
     table.add_column("Name")
@@ -247,48 +248,97 @@ def url(dataset_slug: str) -> None:
         _error(f"Dataset '{e.name}' does not exist.")
 
 
-def dataset_report(dataset_slug: str, granularity: str) -> None:
+def dataset_report(dataset_slug: str, granularity: str, pretty: bool) -> None:
     """
-    Prints a dataset's report.
+    Prints a dataset's report in CSV format.
     Exits the application if no dataset is found.
 
     Parameters
     ----------
-    dataset_slug: str
+    dataset_slug : str
         The dataset's slug.
-    granularity: str
-        Granualarity of the report, can be 'day', 'week' or 'month'.
+    granularity : str
+        Granularity of the report, can be 'day', 'week' or 'month'.
+    pretty : bool
+        If ``True``, it will print the output in a Rich formatted table.
     """
     client: Client = _load_client(offline=True)
+    console = Console(theme=_console_theme())
     try:
         remote_dataset: RemoteDataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
         report: str = remote_dataset.get_report(granularity)
-        print(report)
+
+        if not pretty:
+            # if no one worked in the report, we print nothing
+            print(report)
+            return
+
+        lines: List[str] = report.split("\n")
+        lines.pop(0)  # remove csv headers
+
+        if not lines:
+            console.print("No one has worked on this dataset yet!\n", style="success")
+            return
+
+        lines.pop()  # remove last line, which is empty
+
+        table: Table = Table(show_header=True, header_style="bold cyan")
+        table.add_column("Date")
+        table.add_column("Dataset Id", justify="right")
+        table.add_column("Dataset Name", justify="right")
+        table.add_column("User Id", justify="right")
+        table.add_column("Email", justify="right")
+        table.add_column("First Name", justify="right")
+        table.add_column("Last Name", justify="right")
+        table.add_column("Annotation Time", justify="right")
+        table.add_column("Annotations Approved", justify="right")
+        table.add_column("Annotations Created", justify="right")
+        table.add_column("Images Annotated", justify="right")
+        table.add_column("Images Approved", justify="right")
+        table.add_column("Images Rejected", justify="right")
+
+        for row in lines:
+            table.add_row(*row.split(","))
+
+        console.print(table)
     except NotFound:
         _error(f"Dataset '{dataset_slug}' does not exist.")
 
 
 def export_dataset(
-    dataset_slug: str, include_url_token: bool, name: str, annotation_class_ids: Optional[List[str]] = None
+    dataset_slug: str,
+    include_url_token: bool,
+    name: str,
+    annotation_class_ids: Optional[List[str]] = None,
+    include_authorship: bool = False,
 ) -> None:
     """
     Create a new release for the dataset.
 
     Parameters
     ----------
-    dataset_slug: str
+    dataset_slug : str
         Slug of the dataset to which we perform the operation on.
-    include_url_token: bool
-        If True includes the url token, if False does not.
-    name: str
+    include_url_token : bool, default: False
+        If ``True`` includes the url token, if ``False`` does not.
+    name : str
         Name of the release.
-    annotation_class_ids: Optional[List[str]]
-        List of the classes to filter. Defautls to None.
+    annotation_class_ids : Optional[List[str]], default: None
+        List of the classes to filter.
+    include_authorship : bool, default: False
+        If ``True`` include annotator and reviewer metadata for each annotation.
     """
     client: Client = _load_client(offline=False)
     identifier: DatasetIdentifier = DatasetIdentifier.parse(dataset_slug)
     ds: RemoteDataset = client.get_remote_dataset(identifier)
-    ds.export(annotation_class_ids=annotation_class_ids, name=name, include_url_token=include_url_token)
+
+    ds.export(
+        annotation_class_ids=annotation_class_ids,
+        name=name,
+        include_url_token=include_url_token,
+        include_authorship=include_authorship,
+    )
+
     identifier.version = name
     print(f"Dataset {dataset_slug} successfully exported to {identifier}")
     print_new_version_info(client)
@@ -523,7 +573,7 @@ def upload_data(
     preserve_folders : bool
         Specify whether or not to preserve folder paths when uploading.
     verbose : bool
-        Specify whther to have full traces print when uploading files or not.
+        Specify whether to have full traces print when uploading files or not.
     """
     client: Client = _load_client()
     try:
@@ -740,12 +790,21 @@ def list_files(
         if not sort_by:
             sort_by = "updated_at:desc"
 
+        table: Table = Table(show_header=True, header_style="bold cyan")
+        table.add_column("Name", justify="left")
+
+        if not only_filenames:
+            table.add_column("Status", justify="left")
+            table.add_column("URL", justify="left")
+
         for file in dataset.fetch_remote_files(filters, sort_by):
             if only_filenames:
-                print(file.filename)
+                table.add_row(file.filename)
             else:
                 image_url = dataset.workview_url_for_item(file)
-                print(f"{file.filename}\t{file.status if not file.archived else 'archived'}\t {image_url}")
+                table.add_row(file.filename, f"{file.status if not file.archived else 'archived'}", image_url)
+
+        Console().print(table)
     except NotFound as e:
         _error(f"No dataset with name '{e.name}'")
     except ValueError as e:
@@ -792,25 +851,30 @@ def delete_files(dataset_slug: str, files: List[str], skip_user_confirmation: bo
 
     Parameters
     ----------
-    dataset_slug: str
+    dataset_slug : str
         The dataset's slug.
-    files: List[str]
+    files : List[str]
         The list of filenames to delete.
-    skip_user_confirmation: bool
-        If True, skips user confirmation, if False it will prompt the user. Defaults to False.
+    skip_user_confirmation : bool, default: False
+        If ``True``, skips user confirmation, if False it will prompt the user.
     """
     client: Client = _load_client(dataset_identifier=dataset_slug)
     try:
-        console = Console()
+        console = Console(theme=_console_theme(), stderr=True)
         dataset: RemoteDataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
-        items: Iterator[DatasetItem] = dataset.fetch_remote_files({"filenames": ",".join(files)})
+        items, items_2 = tee(dataset.fetch_remote_files({"filenames": files}))
         if not skip_user_confirmation and not secure_continue_request():
             console.print("Cancelled.")
             return
 
+        found_filenames: Set[str] = set([item.filename for item in items_2])
+        not_found_filenames: Set[str] = set(files) - found_filenames
+        for filename in not_found_filenames:
+            console.print(f"File not found: {filename}", style="warning")
+
         with console.status("[bold red]Deleting files..."):
             dataset.delete_items(items)
-            console.print("[bold green]Files successfully deleted!")
+            console.print("Operation successfully completed!", style="success")
 
     except NotFound as e:
         _error(f"No dataset with name '{e.name}'")
@@ -826,13 +890,13 @@ def dataset_convert(dataset_identifier: str, format: str, output_dir: Optional[P
 
     Parameters
     ----------
-    dataset_identifier: str
+    dataset_identifier : str
         The dataset identifier, normally in the "<team-slug>/<dataset-slug>:<version>" form.
-    format: str
+    format : str
         The format we want to convert to.
-    output_dir: Optional[PathLike]
+    output_dir : Optional[PathLike], default: None
         The folder where the exported annotation files will be. If None it will be the inside the
-        annotations folder of the dataset under 'other_formats/{format}'. The Defaults to None.
+        annotations folder of the dataset under 'other_formats/{format}'.
     """
     identifier: DatasetIdentifier = DatasetIdentifier.parse(dataset_identifier)
     client: Client = _load_client(team_slug=identifier.team_slug)
@@ -897,7 +961,7 @@ def post_comment(
     dataset_slug: str
         The slug of the dataset the item belongs to.
     filename: str
-        The filename to receive the commment.
+        The filename to receive the comment.
     text: str
         The comment.
     x: float, default: 1
@@ -980,7 +1044,7 @@ def print_new_version_info(client: Optional[Client] = None) -> None:
     Parameters
     ----------
     client: Optional[Client]
-        The client containing information aboue the new verison. Defaults to None.
+        The client containing information about the new version. Defaults to None.
     """
     if not client or not client.newer_darwin_version:
         return
