@@ -1,9 +1,10 @@
 import datetime
+import shutil
 from pathlib import Path
 from typing import Any, Dict, Optional
 
+import requests
 from darwin.dataset.identifier import DatasetIdentifier
-from requests import Response
 
 
 class Release:
@@ -191,15 +192,9 @@ class Release:
         if not self.url:
             raise ValueError("Release must have a valid url to download the zip.")
 
-        from darwin.client import Client
-
-        config_path: Path = Path.home() / ".darwin" / "config.yaml"
-        client: Client = Client.from_config(config_path=config_path, team_slug=self.team_slug)
-
-        data: Response = client.fetch_binary(self.url)
-        with open(path, "wb") as download_file:
-            for chunk in data.iter_content(chunk_size=8192):
-                download_file.write(chunk)
+        with requests.get(self.url, stream=True) as response:
+            with open(path, "wb") as download_file:
+                shutil.copyfileobj(response.raw, download_file)
 
         return path
 
